@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0607';
+our $VERSION = '0.0608';
 
 use Moo;
 use strictures 2;
@@ -40,10 +40,23 @@ has net => (
 
 
 has chord_map => (
-    is      => 'ro',
-    isa     => sub { croak "$_[0] is not an arrayref" unless ref $_[0] eq 'ARRAY' },
-    default => sub { ['', 'm', 'm', '', '', 'm', 'dim'] },
+    is => 'lazy',
 );
+sub _build_chord_map {
+    my ($self) = @_;
+    my %modes = (
+        major      => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
+        ionian     => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
+        dorian     => [ 'm',   'm',   '',    '',    'm',   'dim', ''    ],
+        phrygian   => [ 'm',   '',    '',    'm',   'dim', '',    'm'   ],
+        lydian     => [ '',    '',    'm',   'dim', '',    'm',   'm'   ],
+        mixolydian => [ '',    'm',   'dim', '',    'm',   'm',   ''    ],
+        minor      => [ 'm',   'dim', '',    'm',   'm',   '',    ''    ],
+        aeolian    => [ 'm',   'dim', '',    'm',   'm',   '',    ''    ],
+        locrian    => [ 'dim', '',    'm',   'm',   '',    '',    'm'   ],
+    );
+    return $modes{ $self->scale_name };
+}
 
 
 has scale_name => (
@@ -353,7 +366,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0607
+version 0.0608
 
 =head1 SYNOPSIS
 
@@ -433,7 +446,7 @@ The chord names of each scale position.
 The number of items in this list must be equal to the number of keys
 in the B<net>.
 
-Default: C<[ '', 'm', 'm', '', '', 'm', 'dim' ]>
+Default: C<[ '', 'm', 'm', '', '', 'm', 'dim' ]> (major scale)
 
 Here C<''> refers to the major chord and C<'m'> means minor.
 
